[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- weblogolib: WebLogo (http://code.google.com/p/weblogo/) is a tool for creating sequence logos from biological sequence alignments.
  - weblogolib._cgi
  - weblogolib._cli
  - weblogolib.color: Color specifications using CSS2 (Cascading Style Sheet) syntax.
  - weblogolib.colorscheme: Popular color codings for nucleic and amino acids.
  - weblogolib.logomath